@@ -219,11 +219,14 @@ class PathwayCommons(REST):
         if frmt != "BIOPAX":
             url += "&format=%s" % frmt
 
-        res = self.http_get(url, frmt=None)
+        if frmt.lower() in ["biopax", "sbgn"]: 
+            frmt = "xml"
+        else:
+            frmt = "txt"
+        res = self.http_get(url, frmt=frmt)
 
         return res
 
-
     def top_pathways(self, datasource=None, organism=None):
         """This command returns all *top* pathways
 
@@ -387,7 +390,7 @@ class PathwayCommons(REST):
         if organism:
             params['organism'] = organism
 
-        res = self.http_get(url, frmt=None, params=params)
+        res = self.http_get(url, frmt="txt", params=params)
         return res
 
     def traverse(self, uri, path):
@@ -460,7 +463,7 @@ class PathwayCommons(REST):
 
         url += "&path=" + path
 
-        res = self.http_get(url, frmt=None)
+        res = self.http_get(url, frmt="json")
         return res
 
 
